Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(68)

Unified Diff: media/video/capture/screen/screen_capturer.h

Issue 12047101: Move screen capturers from remoting/capturer to media/video/capturer/screen (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/video/capture/screen/screen_capturer.h
diff --git a/remoting/capturer/video_frame_capturer.h b/media/video/capture/screen/screen_capturer.h
similarity index 81%
rename from remoting/capturer/video_frame_capturer.h
rename to media/video/capture/screen/screen_capturer.h
index 2b6c803916ce93d0716e381ffe8f31c5e9e7338b..0d34871139455494765a8026db040834086ead51 100644
--- a/remoting/capturer/video_frame_capturer.h
+++ b/media/video/capture/screen/screen_capturer.h
@@ -2,17 +2,18 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef REMOTING_CAPTURER_VIDEO_FRAME_CAPTURER_H_
-#define REMOTING_CAPTURER_VIDEO_FRAME_CAPTURER_H_
+#ifndef MEDIA_VIDEO_CAPTURE_SCREEN_SCREEN_CAPTURER_H_
+#define MEDIA_VIDEO_CAPTURE_SCREEN_SCREEN_CAPTURER_H_
#include "base/basictypes.h"
#include "base/callback.h"
#include "base/shared_memory.h"
+#include "media/base/media_export.h"
#include "third_party/skia/include/core/SkRegion.h"
-namespace remoting {
+namespace media {
-class CaptureData;
+class ScreenCaptureData;
struct MouseCursorShape;
class SharedBufferFactory;
@@ -46,7 +47,7 @@ class SharedBufferFactory;
// Implementation has to ensure the following guarantees:
// 1. Double buffering
// Since data can be read while another capture action is happening.
-class VideoFrameCapturer {
+class MEDIA_EXPORT ScreenCapturer {
public:
// Provides callbacks used by the capturer to pass captured video frames and
// mouse cursor shapes to the processing pipeline.
@@ -55,7 +56,7 @@ class VideoFrameCapturer {
// Called when a video frame has been captured. |capture_data| describes
// a captured frame.
virtual void OnCaptureCompleted(
- scoped_refptr<CaptureData> capture_data) = 0;
+ scoped_refptr<ScreenCaptureData> capture_data) = 0;
// Called when the cursor shape has changed.
// TODO(sergeyu): Move cursor shape capturing to a separate class.
@@ -66,26 +67,26 @@ class VideoFrameCapturer {
virtual ~Delegate() {}
};
- virtual ~VideoFrameCapturer() {}
+ virtual ~ScreenCapturer() {}
// Create platform-specific capturer.
- static scoped_ptr<VideoFrameCapturer> Create();
+ static scoped_ptr<ScreenCapturer> Create();
// Create platform-specific capturer that uses shared memory buffers.
- static scoped_ptr<VideoFrameCapturer> CreateWithFactory(
+ static scoped_ptr<ScreenCapturer> CreateWithFactory(
SharedBufferFactory* shared_buffer_factory);
#if defined(OS_LINUX)
// Set whether the VideoFrameCapturer should try to use X DAMAGE support if it
// is available. This needs to be called before the VideoFrameCapturer is
// created.
// This is used by the Virtual Me2Me host, since the XDamage extension is
// known to work reliably in this case.
// TODO(lambroslambrou): This currently sets a global flag, referenced during
// VideoFrameCapturer::Create(). This is a temporary solution, until the
// DesktopEnvironment class is refactored to allow applications to control
// the creation of various stubs (including the VideoFrameCapturer) - see
// http://crbug.com/104544
static void EnableXDamage(bool enable);
#endif // defined(OS_LINUX)
@@ -110,6 +111,6 @@ class VideoFrameCapturer {
virtual void CaptureFrame() = 0;
};
-} // namespace remoting
+} // namespace media
-#endif // REMOTING_CAPTURER_VIDEO_FRAME_CAPTURER_H_
+#endif // MEDIA_VIDEO_CAPTURE_SCREEN_SCREEN_CAPTURER_H_
« no previous file with comments | « media/video/capture/screen/screen_capture_frame_queue.cc ('k') | media/video/capture/screen/screen_capturer_fake.h » ('j') | no next file with comments »

Powered by Google App Engine
@@ -66,26 +67,26 @@ class VideoFrameCapturer {
SharedBufferFactory* shared_buffer_factory);
#if defined(OS_LINUX)
- // Set whether the VideoFrameCapturer should try to use X DAMAGE support if it
- // is available. This needs to be called before the VideoFrameCapturer is
+ // Set whether the ScreenCapturer should try to use X DAMAGE support if it
+ // is available. This needs to be called before the ScreenCapturer is
// created.
// This is used by the Virtual Me2Me host, since the XDamage extension is
@@ -66,26 +67,26 @@ class VideoFrameCapturer {
// known to work reliably in this case.
// TODO(lambroslambrou): This currently sets a global flag, referenced during
- // VideoFrameCapturer::Create(). This is a temporary solution, until the
+ // ScreenCapturer::Create(). This is a temporary solution, until the
// DesktopEnvironment class is refactored to allow applications to control
@@ -66,26 +67,26 @@ class VideoFrameCapturer {
// DesktopEnvironment class is refactored to allow applications to control
- // the creation of various stubs (including the VideoFrameCapturer) - see
+ // the creation of various stubs (including the ScreenCapturer) - see
// http://crbug.com/104544
static void EnableXDamage(bool enable);
This is Rietveld 408576698